@@ -29,6 +29,7 @@ int optimize = FALSE;
 int histogram = FALSE;
 int interlaced = PNG_INTERLACE_LAST;
 int progress = FALSE;
+int transparent_ok = FALSE;
 int verbose = FALSE;
 int recover = FALSE;
 int webconvert = FALSE;
@@ -651,7 +652,8 @@ int processfile(char *fname, FILE *fp)
 	    fprintf(stderr, "gif2png: %s is multi-image\n", fname);
 	    return 0;
 	}
-	else if (current->imagestruct && current->imagestruct->trans != -1)
+	else if (!transparent_ok
+		 && current->imagestruct && current->imagestruct->trans != -1)
 	{
 	    fprintf(stderr, "gif2png: %s has a transparency color\n", fname);
 	    return 0;
@@ -796,6 +798,10 @@ int main(int argc, char *argv[])
 		software_chunk = FALSE;
 		break;
 
+	    case 't':
+		transparent_ok = TRUE;
+		break;
+
 	    case 'v':
 		++verbose;
 		break;
@@ -813,7 +819,7 @@ int main(int argc, char *argv[])
 	    usage:
 		fprintf(stderr,
 	"\n"
-	"usage: gif2png [ -bdfghinprsvwO ] [file[.gif]] ...\n"
+	"usage: gif2png [ -bdfghinprstvwO ] [file[.gif]] ...\n"
 	"\n"
 	"   -b  replace background pels with given RRGGBB color (hex digits)\n"
 	"   -d  delete source GIF files after successful conversion\n"
@@ -824,6 +830,7 @@ int main(int argc, char *argv[])
 	"   -p  display progress of PNG writing in %%\n"
 	"   -r  try to recover corrupted GIF files\n"
 	"   -s  do not write Software text chunk\n"
+	"   -t  transparency OK, web probe mode wccepts transparent GIFs\n"
 	"   -v  verbose; display conversion statistics and debugging messages\n"
 	"   -w  web probe, list images without animation or transparency\n"
 	"   -O  optimize; remove unused color-table entries; use zlib level 9\n"
